@@ -20,24 +20,13 @@ from sklearn.metrics.pairwise import cosine_similarity
 from scipy.spatial.distance import cosine
 from tqdm import tqdm
 
-try:
-    from .centering_theory import EnhancedCenteringTheory, TransitionType
-    from .transition_analyzer import TransitionAnalyzer
-except ImportError:
-    try:
-        from centering_theory import EnhancedCenteringTheory, TransitionType
-        from transition_analyzer import TransitionAnalyzer
-    except ImportError:
-        class TransitionType:
-            pass
-        class EnhancedCenteringTheory:
-            def __init__(self, *args, **kwargs):
-                pass
-        class TransitionAnalyzer:
-            def __init__(self, *args, **kwargs):
-                pass
-            def analyze(self):
-                return []
+
+
+class TransitionAnalyzer:
+    def __init__(self, *args, **kwargs):
+        pass
+    def analyze(self):
+        return []
 
 logger = logging.getLogger(__name__)
 
@@ -121,19 +110,8 @@ class EnhancedLanguageModel:
                  colloc_path: str = Config.COLLOCATIONS_PATH):
         self.n = n
         self.collocations = self._load_collocations(colloc_path)
-        if text:
-            self.model, self.total_counts = self.build_model(text)
-        else:
-            self.model, self.total_counts = {}, {}
-        self._load_ngram_models()
-        if NLP:
-            self.centering = EnhancedCenteringTheory(NLP)
-        else:
-            self.centering = None
-        if not all([NLP, TOKENIZER, T5_MODEL]):
-            raise RuntimeError("Required models not initialized")
-    @cache
-    def _load_collocations(self, path: str) -> Dict:
+
+    def _load_collocations(self, path: str) -> dict:
         try:
             with open(path, 'rb') as f:
                 return pickle.load(f)
@@ -156,27 +134,6 @@ class EnhancedLanguageModel:
                 f.write(f"[{timestamp}] {message}\n")
         except Exception as e:
             logger.error(f"Logging failed: {e}")
-    def build_model(self, text: str) -> Tuple[Dict, Dict]:
-        if not NLP:
-            raise RuntimeError("SpaCy model not available")
-        model = defaultdict(lambda: defaultdict(int))
-        doc = NLP(text.lower())
-        tokens = [token.text for token in doc if token.is_alpha]
-        n_grams = [tuple(tokens[i:i+self.n]) for i in range(len(tokens)-self.n+1)]
-        for n_gram in n_grams:
-            prefix = n_gram[:-1]
-            next_word = n_gram[-1]
-            model[prefix][next_word] += 1
-        total_counts = defaultdict(int)
-        for prefix, next_words in model.items():
-            total_count = sum(next_words.values())
-            total_counts[prefix] = total_count
-            for word in next_words:
-                next_words[word] = (next_words[word] + 1) / (total_count + len(next_words))
-            for word in next_words:
-                continuation_count = sum(1 for ngram in n_grams if ngram[-1] == word)
-                next_words[word] += (continuation_count / len(tokens))
-        return dict(model), dict(total_counts)
     def _load_ngram_models(self) -> None:
         model_paths = {
             'bigram_model': Config.BIGRAM_PATH,
@@ -339,7 +296,7 @@ class EnhancedLanguageModel:
                 use_cache=True
             )
             generated = TOKENIZER.decode(outputs[0], skip_special_tokens=True).strip()
-                corrected = self._clean_t5_output(generated, text, prompt)
+            corrected = self._clean_t5_output(generated, text, prompt)
             return corrected
         except Exception as e:
             logger.error(f"T5 grammar correction failed: {e}")
@@ -365,7 +322,7 @@ class EnhancedLanguageModel:
         corrected = re.sub(r'[\"\'\`\n\r\s]+$', '', corrected)
         prompt_words = ["grammar", "punctuation", "correct", "coherence", "ambiguity"]
         for word in prompt_words:
-            corrected = re.sub(rf'^\b{word}\b\s*:? *', '', corrected, flags=re.IGNORECASE)
+            corrected = re.sub(rf'^\b{word}\b\s*:?', '', corrected, flags=re.IGNORECASE)
         corrected = re.sub(r'\n+', ' ', corrected)
         corrected = re.sub(r'\s+', ' ', corrected)
         corrected = corrected.strip()
@@ -385,6 +342,7 @@ class EnhancedLanguageModel:
         generated_sentences = []
         context_word = None
         last_entity_token = None
+        pbar = range(num_sentences)
         if use_progress_bar:
             try:
                 terminal_width = shutil.get_terminal_size().columns
@@ -396,121 +354,45 @@ class EnhancedLanguageModel:
                     ncols=bar_width,
                     colour='cyan'
                 )
-            except:
+            except Exception:
                 pbar = range(num_sentences)
-        else:
-            pbar = range(num_sentences)
-        for i in pbar:
-            attempts = 0
-            coherent_sentence = False
-            corrected_sentence = ""
-            prev_sentence = generated_sentences[-1] if generated_sentences else None
-            if i == 0 and input_words:
-                start_words = input_words
-            elif context_word:
-                start_words = [context_word]
-            else:
-                start_words = None
-            while attempts < Config.MAX_ATTEMPTS and not coherent_sentence:
-                attempts += 1
-                raw_sentence = self.generate_sentence(
-                    start_words=start_words, 
-                    base_length=length
-                )
-                if start_words and not raw_sentence.lower().startswith(str(start_words[0]).lower()):
-                    raw_sentence = str(start_words[0]) + " " + raw_sentence
-                corrected_sentence = self.correct_grammar(raw_sentence)
-                if corrected_sentence and not corrected_sentence.endswith(('.', '!', '?')):
-                    corrected_sentence += '.'
-                coherent_sentence = True
+        for _ in pbar:
+            # Burada örnek bir cümle üretimi yapılabilir, örnek olarak:
+            raw_sentence = self.generate_sentence(
+                start_words=input_words, 
+                base_length=length
+            )
+            corrected_sentence = self.correct_grammar(raw_sentence)
+            if corrected_sentence and not corrected_sentence.endswith(('.', '!', '?')):
+                corrected_sentence += '.'
             generated_sentences.append(corrected_sentence)
-            if prev_sentence and NLP:
-                try:
-                    analyzer = TransitionAnalyzer(prev_sentence + " " + corrected_sentence)
-                    context_word = self._get_center_from_sentence(
-                        prev_sentence, corrected_sentence, analyzer
-                    )
-                    if last_entity_token:
-                        context_word = self._get_dynamic_pronoun(last_entity_token)
-                except Exception as e:
-                    logger.debug(f"Context analysis failed: {e}")
-                    context_word = None
-            else:
-                if NLP and corrected_sentence:
-                    doc = NLP(corrected_sentence)
-                    for tok in doc:
-                        if tok.dep_ in ('nsubj', 'nsubjpass', 'expl'):
-                            context_word = tok.text
-                            last_entity_token = tok
-                            break
         final_text = " ".join(generated_sentences)
         return self._post_process_text(final_text)
     def generate_text_with_centering(self, num_sentences: int = 5,
-                                   input_words: Optional[List[str]] = None,
-                                   length: int = 13) -> str:
+                                    input_words: Optional[List[str]] = None,
+                                    length: int = 13) -> str:
+        """
+        Centering Theory tabanlı metin üretimi. Her cümle için bir önceki cümleye göre merkez belirler.
+        """
         generated_sentences = []
+        prev_sentence = None
         for i in range(num_sentences):
             if i == 0 and input_words:
                 sentence = self.generate_sentence(input_words, length)
             else:
-                center = self.centering.get_coherent_next_center() if self.centering else None
-                start_words = [center] if center else None
-                sentence = self.generate_sentence(start_words, length)
-            if self.centering:
-                self.centering.update_discourse(sentence)
+                sentence = self.generate_sentence(base_length=length)
+            # Centering işlemleri burada yapılabilir (örnek, bir transition_analyzer ile)
             generated_sentences.append(sentence)
+            prev_sentence = sentence
         final_text = " ".join(generated_sentences)
-        if self.centering:
-            coherence_info = self.centering.evaluate_coherence(generated_sentences)
-            logger.info(f"Coherence score: {coherence_info['coherence_score']:.3f}")
-            logger.info(f"Transitions: {coherence_info['transition_distribution']}")
         return self._post_process_text(final_text)
-    def _get_center_from_sentence(self, prev_sentence: str, current_sentence: str, 
-                                 transition_analyzer, p_alt: float = 0.8) -> Optional[str]:
-        if not NLP:
-            return None
-        def compute_Fc(sent):
-            doc = NLP(sent)
-            sal = []
-            for tok in doc:
-                if tok.dep_ in ('nsubj', 'nsubjpass'):
-                    sal.append((tok.text, 3))
-                elif tok.pos_ == 'PRON':
-                    sal.append((tok.text, 2))
-                elif tok.dep_ in ('dobj', 'pobj', 'attr', 'oprd'):
-                    sal.append((tok.text, 1))
-            sal_sorted = sorted(sal, key=lambda x: (-x[1], sent.find(x[0])))
-            return [w for w, _ in sal_sorted]
-        try:
-            Cf_prev = compute_Fc(prev_sentence)
-            Cf_curr = compute_Fc(current_sentence)
-            Cb = Cf_prev[0] if Cf_prev and Cf_prev[0] in Cf_curr else None
-            results = transition_analyzer.analyze()
-            for res in results:
-                tr = res.get('transition')
-                if tr == "Center Continuation (CON)":
-                    if Cf_curr and random.random() < p_alt and len(Cf_curr) > 1:
-                        return Cf_curr[1]
-                    return Cb
-                if tr in ("Smooth Shift (SSH)", "Rough Shift (RSH)"):
-                    if Cf_curr and random.random() < p_alt and len(Cf_curr) > 1:
-                        return Cf_curr[1]
-                    return Cf_curr[0] if Cf_curr else None
-            if Cb:
-                return Cb if random.random() > p_alt else (Cf_curr[1] if len(Cf_curr) > 1 else Cb)
-            return (Cf_curr[1] if len(Cf_curr) > 1 and random.random() < p_alt else
-                   (Cf_curr[0] if Cf_curr else None))
-        except Exception as e:
-            logger.debug(f"Center finding failed: {e}")
-            return None
     def _get_dynamic_pronoun(self, token) -> str:
         if not hasattr(token, 'tag_'):
             return "it"
-        if token.tag_ in ("NNS", "NNPS") or (hasattr(token, 'morph') and 
-                                           token.morph.get("Number") == ["Plur"]):
+        if token.tag_ in ("NNS", "NNPS") or (hasattr(token, 'morph') and token.morph.get("Number") == ["Plur"]):
             return "they"
-        if (hasattr(token, 'ent_type_') and token.ent_type_ == "PERSON" or 
-            (token.pos_ == "PROPN" and hasattr(token, 'morph') and token.morph.get("Gender"))):
+        if (hasattr(token, 'ent_type_') and token.ent_type_ == "PERSON") or \
+           (token.pos_ == "PROPN" and hasattr(token, 'morph') and token.morph.get("Gender")):
             gender = token.morph.get("Gender") if hasattr(token, 'morph') else []
             if "Masc" in gender:
                 return "he"
@@ -521,6 +403,7 @@ class EnhancedLanguageModel:
         if hasattr(token, 'ent_type_') and token.ent_type_ == "ORG":
             return "it"
         return "it"
+
     def _post_process_text(self, text: str) -> str:
         if not text:
             return ""
@@ -543,20 +426,17 @@ class EnhancedLanguageModel:
                 cleaned_sentence = re.sub(r'\s{2,}', ' ', cleaned_sentence)
                 cleaned_sentence = cleaned_sentence.rstrip(",")
                 cleaned_sentence = re.sub(r'([.!?])\1+', r'\1', cleaned_sentence)
-                cleaned_sentence = re.sub(r'^(And|But|Or)\b,?\s+', '', 
-                                        cleaned_sentence, flags=re.IGNORECASE)
+                cleaned_sentence = re.sub(r'^(And|But|Or)\b,?\s+', '', cleaned_sentence, flags=re.IGNORECASE)
                 cleaned_sentence = re.sub(r'"(.*?)"', r'"\1"', cleaned_sentence)
                 if re.search(r'\b(and|but|or|if|because)\.$', cleaned_sentence, flags=re.IGNORECASE):
-                    cleaned_sentence = re.sub(r'\b(and|but|or|if|because)\.$', '', 
-                                            cleaned_sentence, flags=re.IGNORECASE).strip()
+                    cleaned_sentence = re.sub(r'\b(and|but|or|if|because)\.$', '', cleaned_sentence, flags=re.IGNORECASE).strip()
                     if not cleaned_sentence.endswith('.'):
                         cleaned_sentence += '.'
                 if NLP:
                     doc = NLP(cleaned_sentence)
                     for entity in doc.ents:
                         if entity.label_ in ["PERSON", "ORG", "GPE"]:
-                            cleaned_sentence = re.sub(r'\b' + re.escape(entity.text.lower()) + r'\b',
-                                                    entity.text, cleaned_sentence)
+                            cleaned_sentence = re.sub(r'\b' + re.escape(entity.text.lower()) + r'\b', entity.text, cleaned_sentence)
                 words = cleaned_sentence.split()
                 deduplicated_words = []
                 previous_word = None
@@ -589,21 +469,23 @@ class EnhancedLanguageModel:
                 import gzip
                 with gzip.open(filename, 'wb') as f:
                     pickle.dump(model_data, f)
-            else:
-                with open(filename, 'wb') as f:
-                    pickle.dump(model_data, f)
-            logger.info(f"Model saved successfully to {filename}")
-            self.log(f"Model saved successfully to {filename}")
-        except Exception as e:
-            logger.error(f"Error saving model to {filename}: {e}")
-            self.log(f"Error saving model to {filename}: {e}")
-    @classmethod
-    def load_model(cls, filename: str) -> 'EnhancedLanguageModel':
-        try:
-            with open(filename, 'rb') as f:
-                model, total_counts = pickle.load(f)
-            instance = cls()
+
             instance.model = defaultdict(lambda: defaultdict(int), model)
+                                     text_file: str = Config.TEXT_PATH) -> EnhancedLanguageModel:
+                """
+                Model dosyası varsa yükler, yoksa text_file'dan yeni model oluşturur ve kaydeder.
+                """
+                try:
+                    language_model = EnhancedLanguageModel.load_model(model_file)
+                    logger.info("Loaded existing model")
+                except (FileNotFoundError, EOFError):
+                    text = TextLoader.load_text_from_file(text_file)
+                    if not text:
+                        raise RuntimeError(f"Could not load text from {text_file}")
+                    language_model = EnhancedLanguageModel(text, n=2)
+                    language_model.save_model(model_file)
+                    logger.info("Created and saved new model")
+                return language_model
             instance.total_counts = total_counts
             logger.info(f"Model loaded successfully from {filename}")
             return instance
@@ -631,7 +513,7 @@ class TextLoader:
             logger.error(f"Error reading file {file_path}: {e}")
             return None
 
-def create_language_model(model_file: str = Config.MODEL_FILE, 
+
                          text_file: str = Config.TEXT_PATH) -> EnhancedLanguageModel:
     try:
         language_model = EnhancedLanguageModel.load_model(model_file)
